@@ -324,3 +324,30 @@ class InfEngineServerEngine:
                     return version
 
         return None
+
+    def clean(self, dl_limit: int = 1):
+        """ Delete useless data. """
+
+        self._logger.info(f"Cleaning InfServer Engine...")
+
+        count = self._clean_multidb(self._engine_dir / INF_ENGINE_PATH_DLDATA, dl_limit)
+
+        if count:
+            self._logger.info(f"Deleted {count} DLData.")
+
+    def _clean_multidb(self, directory: Path, limit: int = 0) -> int:
+        """ Delete several DLData directories from the passed directory. """
+
+        counter = 0
+
+        if directory.is_dir():
+            for obj in directory.iterdir():
+                if limit - counter <= 0:
+                    break
+
+                if obj.is_dir():
+                    self._logger.debug(obj)
+
+                    counter += 1
+
+        return counter
